pub struct SlackRelaxedUrl(pub String);Expand description
This type is needed since Slack allowes invalid URLs in some places like Rich sections and we still need to read them on the client side, so we store it as a string but provide convinent messages to convert to Url if possible.
Tuple Fields
0: StringImplementations
Sourceimpl SlackRelaxedUrl
impl SlackRelaxedUrl
pub fn to_url(&self) -> Result<Url, ParseError>