SlackRelaxedUrl

Struct SlackRelaxedUrl 

pub struct SlackRelaxedUrl(pub String);
This type is needed since Slack allowes invalid URLs in some places like Rich sections and we still need to read them on the client side, so we store it as a string but provide convinent messages to convert to Url if possible.

Tuple Fields

0: String

Implementations

Source

impl SlackRelaxedUrl

pub const fn new(value: String) -> Self

Source

impl SlackRelaxedUrl

pub fn to_url(&self) -> Result<Url, ParseError>